@@ -15,9 +15,6 @@
 
 """The Authorized Views command group for Cloud Bigtable."""
 
-from __future__ import absolute_import
-from __future__ import division
-from __future__ import unicode_literals
 
 from googlecloudsdk.calliope import base
 
