@@ -15,9 +15,6 @@
 
 """Connects to a serial port gateway using SSH."""
 
-from __future__ import absolute_import
-from __future__ import division
-from __future__ import unicode_literals
 
 import sys
 
