@@ -14,9 +14,6 @@
 # limitations under the License.
 """Create cluster command."""
 
-from __future__ import absolute_import
-from __future__ import division
-from __future__ import unicode_literals
 
 import functools
 import string
@@ -253,6 +250,7 @@ def ParseCreateOptionsBase(
     else:
       addons[api_adapter.LUSTRECSIDRIVER] = True
   enable_pod_snapshots = get_default('pod_snapshots_enabled')
+  enable_agent_sandbox = get_default('enable_agent_sandbox')
 
   return api_adapter.CreateClusterOptions(
       accelerators=get_default('accelerator'),
@@ -286,6 +284,7 @@ def ParseCreateOptionsBase(
       dataplane_v2_observability_mode=get_default(
           'dataplane_v2_observability_mode'
       ),
+      enable_ambient_networking=get_default('enable_ambient_networking'),
       disk_type=get_default('disk_type'),
       enable_autorepair=enable_autorepair,
       enable_autoscaling=get_default('enable_autoscaling'),
@@ -590,6 +589,7 @@ def ParseCreateOptionsBase(
       disable_multi_nic_lustre=get_default('disable_multi_nic_lustre'),
       enable_lustre_multi_nic=get_default('enable_lustre_multi_nic'),
       enable_pod_snapshots=enable_pod_snapshots,
+      enable_agent_sandbox=enable_agent_sandbox,
       enable_default_compute_class=get_default('enable_default_compute_class'),
       enable_k8s_certs_via_dns=get_default('enable_k8s_certs_via_dns'),
       boot_disk_provisioned_iops=get_default('boot_disk_provisioned_iops'),
@@ -600,8 +600,12 @@ def ParseCreateOptionsBase(
       control_plane_egress_mode=get_default('control_plane_egress'),
       enable_slice_controller=get_default('enable_slice_controller'),
       autopilot_general_profile=get_default('autopilot_general_profile'),
+      node_architecture_taint_behavior=get_default(
+          'node_architecture_taint_behavior'
+      ),
   )
 
+
 GA = 'ga'
 BETA = 'beta'
 ALPHA = 'alpha'
@@ -744,7 +748,7 @@ flags_to_add = {
         'machinetype': flags.AddMachineTypeFlag,
         'maintenancewindow': flags.AddMaintenanceWindowGroup,
         'maintenancedisruptionbudget': lambda p: (
-            flags.AddMaintenanceDisruptionBudgetFlagGroup(p, hidden=True)
+            flags.AddMaintenanceDisruptionBudgetFlagGroup(p, hidden=False)
         ),
         'managedprometheus': lambda p: flags.AddManagedPrometheusFlags(
             p, for_create=True
@@ -767,6 +771,9 @@ flags_to_add = {
         'nodelabels': flags.AddNodeLabelsFlag,
         'nodelocations': flags.AddNodeLocationsFlag,
         'nodetaints': flags.AddNodeTaintsFlag,
+        'nodearchitecturetaintbehavior': (
+            flags.AddNodeArchitectureTaintBehaviorFlag
+        ),
         'nodeversion': flags.AddNodeVersionFlag,
         'notificationconfig': flags.AddNotificationConfigFlag,
         'num_nodes': flags.AddNumNodes,
@@ -830,6 +837,9 @@ flags_to_add = {
         ),
         'containerdConfig': flags.AddContainerdConfigFlag,
         'secretManagerConfig': flags.AddSecretManagerEnableFlagGroup,
+        'secretSyncConfig': lambda p: flags.AddSecretSyncFlagGroup(
+            p, hidden=True
+        ),
         'InTransitEncryption': flags.AddInTransitEncryptionFlag,
         'enableCiliumClusterwideNetworkPolicy': (
             flags.AddEnableCiliumClusterwideNetworkPolicyFlag
@@ -951,7 +961,7 @@ flags_to_add = {
         'machinetype': flags.AddMachineTypeFlag,
         'maintenancewindow': flags.AddMaintenanceWindowGroup,
         'maintenancedisruptionbudget': lambda p: (
-            flags.AddMaintenanceDisruptionBudgetFlagGroup(p, hidden=True)
+            flags.AddMaintenanceDisruptionBudgetFlagGroup(p, hidden=False)
         ),
         'managedprometheus': lambda p: flags.AddManagedPrometheusFlags(
             p, for_create=True
@@ -977,10 +987,18 @@ flags_to_add = {
         ),
         'networkpolicy': flags.AddNetworkPolicyFlags,
         'nodetaints': flags.AddNodeTaintsFlag,
+        'nodearchitecturetaintbehavior': (
+            flags.AddNodeArchitectureTaintBehaviorFlag
+        ),
         'nodeidentity': flags.AddClusterNodeIdentityFlags,
         'nodeversion': flags.AddNodeVersionFlag,
         'nodelabels': flags.AddNodeLabelsFlag,
         'notificationconfig': flags.AddNotificationConfigFlag,
+        'nodepoolupgradeconcurrencyconfig': (
+            lambda p: flags.AddNodePoolUpgradeConcurrencyConfigFlag(
+                p, hidden=True
+            )
+        ),
         'num_nodes': flags.AddNumNodes,
         'performancemonitoringunit': (
             lambda p: flags.AddPerformanceMonitoringUnit(p, hidden=False)
@@ -1101,6 +1119,7 @@ flags_to_add = {
             lambda p: flags.AddAutopilotPrivilegedAdmissionFlag(p, hidden=True)
         ),
         'podsnapshots': flags.AddPodSnapshotConfigFlags,
+        'agentsandbox': flags.AddAgentSandboxConfigFlags,
         'enableKernelModuleSignatureEnforcement': (
             flags.AddEnableKernelModuleSignatureEnforcementFlag
         ),
@@ -1111,6 +1130,9 @@ flags_to_add = {
             p, hidden=True
         ),
         'autopilotGeneralProfile': flags.AddAutopilotGeneralProfileFlag,
+        'linkedRunnersMode': lambda p: flags.AddLinkedRunnersModeFlag(
+            p, hidden=True
+        ),
     },
     ALPHA: {
         'accelerator': lambda p: AddAcceleratorFlag(p, True, True, True, True),
@@ -1154,6 +1176,7 @@ flags_to_add = {
         'dataplanev2': flags.AddDataplaneV2Flag,
         'dataplanev2metrics': flags.AddDataplaneV2MetricsFlag,
         'dataplanev2obs': flags.AddDataplaneV2ObservabilityFlags,
+        'enableAmbientNetworking': flags.AddEnableAmbientNetworkingFlag,
         'disabledefaultsnat': AddDisableDefaultSnatFlagForClusterCreate,
         'disksize': flags.AddDiskSizeFlag,
         'disktype': flags.AddDiskTypeFlag,
@@ -1194,7 +1217,7 @@ flags_to_add = {
         'maxpodspernode': flags.AddMaxPodsPerNodeFlag,
         'maintenancewindow': flags.AddMaintenanceWindowGroup,
         'maintenancedisruptionbudget': lambda p: (
-            flags.AddMaintenanceDisruptionBudgetFlagGroup(p, hidden=True)
+            flags.AddMaintenanceDisruptionBudgetFlagGroup(p, hidden=False)
         ),
         'managedprometheus': lambda p: flags.AddManagedPrometheusFlags(
             p, for_create=True
@@ -1211,10 +1234,18 @@ flags_to_add = {
         'monitoring': flags.AddMonitoringFlag,
         'networkpolicy': flags.AddNetworkPolicyFlags,
         'nodetaints': flags.AddNodeTaintsFlag,
+        'nodearchitecturetaintbehavior': (
+            flags.AddNodeArchitectureTaintBehaviorFlag
+        ),
         'nodeidentity': flags.AddClusterNodeIdentityFlags,
         'nodeversion': flags.AddNodeVersionFlag,
         'nodelabels': flags.AddNodeLabelsFlag,
         'notificationconfig': flags.AddNotificationConfigFlag,
+        'nodepoolupgradeconcurrencyconfig': (
+            lambda p: flags.AddNodePoolUpgradeConcurrencyConfigFlag(
+                p, hidden=True
+            )
+        ),
         'num_nodes': flags.AddNumNodes,
         'performancemonitoringunit': (
             lambda p: flags.AddPerformanceMonitoringUnit(p, hidden=False)
@@ -1338,6 +1369,7 @@ flags_to_add = {
             lambda p: flags.AddAutopilotPrivilegedAdmissionFlag(p, hidden=True)
         ),
         'podsnapshots': flags.AddPodSnapshotConfigFlags,
+        'agentsandbox': flags.AddAgentSandboxConfigFlags,
         'enableKernelModuleSignatureEnforcement': (
             flags.AddEnableKernelModuleSignatureEnforcementFlag
         ),
@@ -1348,6 +1380,9 @@ flags_to_add = {
             p, hidden=True
         ),
         'autopilotGeneralProfile': flags.AddAutopilotGeneralProfileFlag,
+        'linkedRunnersMode': lambda p: flags.AddLinkedRunnersModeFlag(
+            p, hidden=True
+        ),
     },
 }
 # LINT.ThenChange(create_auto.py:auto_flags)
@@ -1602,6 +1637,9 @@ class CreateBeta(Create):
     ops.enable_experimental_vertical_pod_autoscaling = get_default(
         'enable_experimental_vertical_pod_autoscaling'
     )
+    ops.node_pool_upgrade_concurrency_config = get_default(
+        'node_pool_upgrade_concurrency_config'
+    )
     ops.security_group = get_default('security_group')
     ops.max_surge_upgrade = get_default('max_surge_upgrade')
     ops.max_unavailable_upgrade = get_default('max_unavailable_upgrade')
@@ -1726,6 +1764,7 @@ class CreateBeta(Create):
     ops.enable_managed_mldiagnostics = get_default(
         'enable_managed_mldiagnostics'
     )
+    ops.linked_runners_mode = get_default('linked_runners_mode')
     return ops
 
 
@@ -1846,6 +1885,9 @@ class CreateAlpha(Create):
     ops.enable_runtime_vulnerability_insight = get_default(
         'enable_runtime_vulnerability_insight'
     )
+    ops.node_pool_upgrade_concurrency_config = get_default(
+        'node_pool_upgrade_concurrency_config'
+    )
     ops.patch_update = get_default('patch_update')
     ops.host_maintenance_interval = get_default('host_maintenance_interval')
     ops.contianerd_config_from_file = get_default('contianerd_config_from_file')
@@ -1894,4 +1936,5 @@ class CreateAlpha(Create):
     ops.gpudirect_strategy = get_default('gpudirect_strategy')
     ops.managed_otel_scope = get_default('managed_otel_scope')
     ops.autopilot_general_profile = get_default('autopilot_general_profile')
+    ops.linked_runners_mode = get_default('linked_runners_mode')
     return ops
