@@ -14,9 +14,6 @@
 # limitations under the License.
 """Connects to a Cloud SQL instance."""
 
-from __future__ import absolute_import
-from __future__ import division
-from __future__ import unicode_literals
 
 import atexit
 from http import client as http_client
